@@ -1,8 +1,8 @@
 package URI::Fast;
 # ABSTRACT: A fast(er) URI parser
-$URI::Fast::VERSION = '0.35_1'; # TRIAL
+$URI::Fast::XS_VERSION = $URI::Fast::VERSION = '0.35_2'; # TRIAL
 
-$URI::Fast::VERSION = '0.351';use utf8;
+$URI::Fast::VERSION = '0.352';use utf8;
 use strict;
 use warnings;
 no strict 'refs';
@@ -11,7 +11,7 @@ use Carp;
 use Exporter;
 
 require XSLoader;
-XSLoader::load('URI::Fast');
+XSLoader::load('URI::Fast', $URI::Fast::XS_VERSION);
 
 use Exporter 'import';
 
@@ -202,7 +202,7 @@ URI::Fast - A fast(er) URI parser
 
 =head1 VERSION
 
-version 0.35_1
+version 0.35_2
 
 =head1 SYNOPSIS
 
